<?xml version="1.0" ?><!DOCTYPE TS><TS language="fa_IR" sourcelanguage="en" version="2.0">
<context>
    <name>Account</name>
    <message>
        <location filename="../src/account.cpp" line="331"/>
        <source>Ready</source>
        <extracomment>Account state</extracomment>
        <translation>آماده</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="333"/>
        <source>Registered</source>
        <extracomment>Account state</extracomment>
        <translation>ثبت شده</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="335"/>
        <source>Not Registered</source>
        <extracomment>Account state</extracomment>
        <translation>ثبت نشده</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="337"/>
        <source>Initializing</source>
        <extracomment>Account state</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/account.cpp" line="339"/>
        <source>Trying...</source>
        <extracomment>Account state</extracomment>
        <translation>در حال نوشتن…</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="341"/>
        <source>Error</source>
        <extracomment>Account state</extracomment>
        <translation>خطا</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="343"/>
        <source>Authentication Failed</source>
        <extracomment>Account state</extracomment>
        <translation>تأیید هویت شکست خورد</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="345"/>
        <source>Network unreachable</source>
        <extracomment>Account state</extracomment>
        <translation>شبکه در دسترس نیست</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="347"/>
        <source>Host unreachable</source>
        <extracomment>Account state</extracomment>
        <translation>میزبان در دسترس نیست</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="349"/>
        <source>Stun configuration error</source>
        <extracomment>Account state</extracomment>
        <translation>خطای پیکربندی STUN</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="351"/>
        <source>Stun server invalid</source>
        <extracomment>Account state</extracomment>
        <translation>کارساز STUN نامعتبر است </translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="353"/>
        <source>Service unavailable</source>
        <extracomment>Account state</extracomment>
        <translation>خدمت موجود نیست</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="355"/>
        <source>Unacceptable</source>
        <extracomment>Account state</extracomment>
        <translation>غیرقابل پذیرش</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="357"/>
        <source>Invalid</source>
        <extracomment>Account state</extracomment>
        <translation>نامعتبر</translation>
    </message>
    <message>
        <location filename="../src/account.cpp" line="359"/>
        <source>Request Timeout</source>
        <extracomment>Account state</extracomment>
        <translation>زمان انقضای درخواست</translation>
    </message>
</context>
<context>
    <name>AccountChecksModel</name>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="438"/>
        <source>Configuration</source>
        <translation>پکربندی</translation>
    </message>
</context>
<context>
    <name>BootstrapModel</name>
    <message>
        <location filename="../src/bootstrapmodel.cpp" line="379"/>
        <source>Hostname</source>
        <translation>نام میزبان</translation>
    </message>
    <message>
        <location filename="../src/bootstrapmodel.cpp" line="381"/>
        <source>Port</source>
        <translation>درگاه</translation>
    </message>
</context>
<context>
    <name>Call</name>
    <message>
        <location filename="../src/call.cpp" line="720"/>
        <source>New</source>
        <extracomment>Call state</extracomment>
        <translation>نو</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="723"/>
        <source>Ringing</source>
        <extracomment>Call state</extracomment>
        <translation>در حال زنگ خوردن</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="726"/>
        <source>Calling</source>
        <extracomment>Call state</extracomment>
        <translation>در حال تماس</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="729"/>
        <source>Talking</source>
        <extracomment>Call state</extracomment>
        <translation>در حال صحبت</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="732"/>
        <source>Dialing</source>
        <extracomment>Call state</extracomment>
        <translation>در حال شماره گیری</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="735"/>
        <source>Hold</source>
        <extracomment>Call state</extracomment>
        <translation>نگه داشتن</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="738"/>
        <source>Failed</source>
        <extracomment>Call state</extracomment>
        <translation>شکست خورد</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="741"/>
        <source>Busy</source>
        <extracomment>Call state</extracomment>
        <translation>مشغول</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="744"/>
        <source>Transfer</source>
        <extracomment>Call state</extracomment>
        <translation>انتقال</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="747"/>
        <source>Transfer hold</source>
        <extracomment>Call state</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/call.cpp" line="750"/>
        <source>Over</source>
        <extracomment>Call state</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/call.cpp" line="753"/>
        <source>Error</source>
        <extracomment>Call state</extracomment>
        <translation>خطا</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="756"/>
        <location filename="../src/call.cpp" line="861"/>
        <source>Conference</source>
        <extracomment>Call state</extracomment>
        <translation>نشست</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="759"/>
        <source>Conference (hold)</source>
        <extracomment>Call state</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/call.cpp" line="762"/>
        <source>ERROR</source>
        <extracomment>Call state</extracomment>
        <translation>خطا</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="765"/>
        <source>Searching for</source>
        <extracomment>Call state</extracomment>
        <translation>درحال جستجو برای</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="768"/>
        <source>Aborted</source>
        <extracomment>Call state</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/call.cpp" line="771"/>
        <source>Communication established</source>
        <extracomment>Call state</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/call.cpp" line="865"/>
        <source>Unknown</source>
        <translation>ناشناخته</translation>
    </message>
    <message>
        <location filename="../src/call.cpp" line="2243"/>
        <source>Account: </source>
        <translation>حساب کاربری</translation>
    </message>
</context>
<context>
    <name>CallModel</name>
    <message>
        <location filename="../src/callmodel.cpp" line="920"/>
        <source>Calls</source>
        <translation>تماس‌ها</translation>
    </message>
</context>
<context>
    <name>CallModelPrivate</name>
    <message>
        <location filename="../src/callmodel.cpp" line="555"/>
        <location filename="../src/callmodel.cpp" line="580"/>
        <source>Invalid account</source>
        <translation>حساب کاربری نامعتبر</translation>
    </message>
</context>
<context>
    <name>CallPrivate</name>
    <message>
        <location filename="../src/call.cpp" line="1794"/>
        <source>Aborted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/call.cpp" line="1815"/>
        <source>No account registered!</source>
        <translation>هیچ حسابی ثبت نشده است!</translation>
    </message>
</context>
<context>
    <name>CategorizedBookmarkModel</name>
    <message>
        <location filename="../src/categorizedbookmarkmodel.cpp" line="181"/>
        <source>Most popular</source>
        <extracomment>Most popular contacts</extracomment>
        <translation>محبوب‌ترین‌ها</translation>
    </message>
    <message>
        <location filename="../src/categorizedbookmarkmodel.cpp" line="299"/>
        <source>Contacts</source>
        <translation>مخاطبان</translation>
    </message>
</context>
<context>
    <name>CategorizedContactModel</name>
    <message>
        <location filename="../src/categorizedcontactmodel.cpp" line="401"/>
        <source>Contacts</source>
        <translation>مخاطبین</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="129"/>
        <source>Empty</source>
        <translation>خالی</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="135"/>
        <location filename="../src/private/sortproxies.cpp" line="153"/>
        <source>Unknown</source>
        <translation>ناشناخته</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="141"/>
        <source>Never</source>
        <translation>هرگز</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="147"/>
        <source>Other</source>
        <translation>دیگر</translation>
    </message>
</context>
<context>
    <name>CategorizedHistoryModel</name>
    <message>
        <location filename="../src/categorizedhistorymodel.cpp" line="414"/>
        <source>History</source>
        <translation>تاریخچه</translation>
    </message>
</context>
<context>
    <name>ChainOfTrustModel</name>
    <message>
        <location filename="../src/chainoftrustmodel.cpp" line="173"/>
        <source>Chain of trust</source>
        <translation>ذنجیره اعتماد</translation>
    </message>
</context>
<context>
    <name>CollectionModel</name>
    <message>
        <location filename="../src/collectionmodel.cpp" line="279"/>
        <source>Name</source>
        <translation>نام</translation>
    </message>
</context>
<context>
    <name>ContactSortingCategoryModel</name>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="49"/>
        <source>Name</source>
        <translation>نام</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="50"/>
        <source>Organisation</source>
        <translation>سازمان</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="51"/>
        <source>Recently used</source>
        <translation>به تازگی استفاده شده</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="52"/>
        <source>Group</source>
        <translation>گروه</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="53"/>
        <source>Department</source>
        <translation>بخش</translation>
    </message>
</context>
<context>
    <name>HistorySortingCategoryModel</name>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="57"/>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="58"/>
        <source>Name</source>
        <translation>نام</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="59"/>
        <source>Popularity</source>
        <translation>محبوبیت</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="60"/>
        <source>Duration</source>
        <translation>مت زمان</translation>
    </message>
    <message>
        <location filename="../src/private/sortproxies.cpp" line="61"/>
        <source>Total time</source>
        <translation>زمان کل</translation>
    </message>
</context>
<context>
    <name>HistoryTimeCategoryModel</name>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="40"/>
        <source>Today</source>
        <translation>امروز</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="41"/>
        <source>Yesterday</source>
        <translation>دیروز</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="48"/>
        <source>Two weeks ago</source>
        <translation>دو هفته پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="49"/>
        <source>Three weeks ago</source>
        <translation>سه هفته پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="47"/>
        <source>A week ago</source>
        <translation>هفته پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="50"/>
        <source>A month ago</source>
        <translation>ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="51"/>
        <source>Two months ago</source>
        <translation>دو ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="52"/>
        <source>Three months ago</source>
        <translation>سه ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="53"/>
        <source>Four months ago</source>
        <translation>چهار ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="54"/>
        <source>Five months ago</source>
        <translation>پنج ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="55"/>
        <source>Six months ago</source>
        <translation>شش ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="56"/>
        <source>Seven months ago</source>
        <translation>هفت ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="57"/>
        <source>Eight months ago</source>
        <translation>هشت ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="58"/>
        <source>Nine months ago</source>
        <translation>نه ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="59"/>
        <source>Ten months ago</source>
        <translation>ده ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="60"/>
        <source>Eleven months ago</source>
        <translation>یازده ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="61"/>
        <source>Twelve months ago</source>
        <translation>دوازده ماه پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="62"/>
        <source>A year ago</source>
        <translation>سال پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="63"/>
        <source>Very long time ago</source>
        <translation>خیلی وقت پیش</translation>
    </message>
    <message>
        <location filename="../src/historytimecategorymodel.cpp" line="64"/>
        <source>Never</source>
        <translation>هرگز</translation>
    </message>
</context>
<context>
    <name>InstantMessagingModel</name>
    <message>
        <location filename="../src/media/textrecording.cpp" line="816"/>
        <source>Me</source>
        <translation>من</translation>
    </message>
</context>
<context>
    <name>MacroModel</name>
    <message>
        <location filename="../src/macromodel.cpp" line="157"/>
        <source>Macros</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/macromodel.cpp" line="263"/>
        <source>New</source>
        <translation>نو</translation>
    </message>
    <message>
        <location filename="../src/macromodel.cpp" line="264"/>
        <source>Other</source>
        <translation>دیگر</translation>
    </message>
</context>
<context>
    <name>MacroModelPrivate</name>
    <message>
        <location filename="../src/macromodel.cpp" line="77"/>
        <source>Other</source>
        <translation>دیگر</translation>
    </message>
</context>
<context>
    <name>Media::RecordingModel</name>
    <message>
        <location filename="../src/media/recordingmodel.cpp" line="189"/>
        <source>Recordings</source>
        <translation>ضبط شده‌ها</translation>
    </message>
    <message>
        <location filename="../src/media/recordingmodel.cpp" line="259"/>
        <source>Text messages</source>
        <translation>پیام‌های متنی</translation>
    </message>
    <message>
        <location filename="../src/media/recordingmodel.cpp" line="264"/>
        <source>Audio/Video</source>
        <translation>صدا/تصویر</translation>
    </message>
</context>
<context>
    <name>NumberCategoryModel</name>
    <message>
        <location filename="../src/numbercategorymodel.cpp" line="56"/>
        <source>Uncategorized</source>
        <translation>دسته‌بندی نشده</translation>
    </message>
</context>
<context>
    <name>NumberCompletionModel</name>
    <message>
        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
        <source>URI</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
        <source>Name</source>
        <translation>نام</translation>
    </message>
    <message>
        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
        <source>Account</source>
        <translation>حساب کاربری</translation>
    </message>
    <message>
        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
        <source>Weight</source>
        <translation>وزن</translation>
    </message>
</context>
<context>
    <name>PersonModel</name>
    <message>
        <location filename="../src/personmodel.cpp" line="171"/>
        <source>Persons</source>
        <translation>افراد</translation>
    </message>
</context>
<context>
    <name>PhoneDirectoryModel</name>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="234"/>
        <source>This account does not support presence tracking</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="237"/>
        <source>No associated account</source>
        <translation>بدون حساب مرتبط</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>URI</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>Type</source>
        <translation>نوع</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>Person</source>
        <translation>شخص</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>Account</source>
        <translation>حساب کاربری</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>State</source>
        <translation>وضعیت</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>Call count</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="305"/>
        <source>Week count</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Trimester count</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Have Called</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Last used</source>
        <translation>آخرین استفاده</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Name_count</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Total (in seconds)</source>
        <translation>مجموع (به ثانیه)</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="306"/>
        <source>Popularity_index</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Bookmarked</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Tracked</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Present</source>
        <translation>حاضر</translation>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Presence message</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Uid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Has certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/phonedirectorymodel.cpp" line="307"/>
        <source>Registered name</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PresenceStatusModel</name>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="197"/>
        <source>Name</source>
        <translation>نام</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="197"/>
        <source>Message</source>
        <translation>پیام</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="197"/>
        <source>Color</source>
        <translation>رنگ</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="197"/>
        <source>Present</source>
        <translation>حاضر</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="197"/>
        <source>Default</source>
        <translation>پیش‌گزیده</translation>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="308"/>
        <location filename="../src/presencestatusmodel.cpp" line="361"/>
        <source>Custom</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/presencestatusmodel.cpp" line="308"/>
        <location filename="../src/presencestatusmodel.cpp" line="310"/>
        <location filename="../src/presencestatusmodel.cpp" line="354"/>
        <location filename="../src/presencestatusmodel.cpp" line="361"/>
        <source>N/A</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ProfileModel</name>
    <message>
        <location filename="../src/profilemodel.cpp" line="637"/>
        <source>Profiles</source>
        <translation>پروفایل ها</translation>
    </message>
</context>
<context>
    <name>ProfileModelPrivate</name>
    <message>
        <location filename="../src/profilemodel.cpp" line="751"/>
        <source>New profile</source>
        <translation>پروفایل جدید</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/accountstatusmodel.cpp" line="177"/>
        <source>Message</source>
        <translation>پیام</translation>
    </message>
    <message>
        <location filename="../src/accountstatusmodel.cpp" line="179"/>
        <source>Code</source>
        <translation>کد</translation>
    </message>
    <message>
        <location filename="../src/accountstatusmodel.cpp" line="181"/>
        <source>Time</source>
        <translation>زمان</translation>
    </message>
    <message>
        <location filename="../src/accountstatusmodel.cpp" line="183"/>
        <source>Counter</source>
        <translation>شمارنده</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="42"/>
        <source>Has a private key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="43"/>
        <source>Is not expired</source>
        <translation>منقضی نشده است</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="44"/>
        <source>Has strong signing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="45"/>
        <source>Is not self signed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="46"/>
        <source>Have a matching key pair</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="47"/>
        <source>Has the right private key file permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="48"/>
        <source>Has the right public key file permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="49"/>
        <source>Has the right private key directory permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="50"/>
        <source>Has the right public key directory permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="51"/>
        <source>Has the right private key directory location</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="52"/>
        <source>Has the right public key directory location</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="53"/>
        <source>Has the right private key SELinux attributes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="54"/>
        <source>Has the right public key SELinux attributes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="55"/>
        <source>The certificate file exist and is readable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="56"/>
        <source>The file is a valid certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="57"/>
        <source>The certificate has a valid authority</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="58"/>
        <source>The certificate has a known authority</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="59"/>
        <source>The certificate is not revoked</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="60"/>
        <source>The certificate authority match</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="61"/>
        <source>The certificate has the expected owner</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="62"/>
        <source>The certificate is within its active period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="90"/>
        <source>Expiration date</source>
        <translation>تاریخ انقضاء</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="91"/>
        <source>Activation date</source>
        <translation>تاریخ فعال سازی</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="92"/>
        <source>Require a private key password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="93"/>
        <source>Public signature</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="94"/>
        <source>Version</source>
        <translation>نگارش</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="95"/>
        <source>Serial number</source>
        <translation>شماره سریال</translation>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="96"/>
        <source>Issuer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="97"/>
        <source>Subject key algorithm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="98"/>
        <source>Common name (CN)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="99"/>
        <source>Name (N)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="100"/>
        <source>Organization (O)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="101"/>
        <source>Signature algorithm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="102"/>
        <source>Md5 fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="103"/>
        <source>Sha1 fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="104"/>
        <source>Public key id</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="105"/>
        <source>Issuer domain name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="106"/>
        <source>Next expected update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificate.cpp" line="107"/>
        <source>Outgoing server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="183"/>
        <source>Local certificate store</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="267"/>
        <location filename="../src/localprofilecollection.cpp" line="220"/>
        <source>Default</source>
        <translation>پیش‌گزیده</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="267"/>
        <source>Certificate not associated with a group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="397"/>
        <source>A certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="397"/>
        <source>An organisation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="420"/>
        <source>Details</source>
        <translation>جزییات</translation>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="420"/>
        <source>The content of the certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="421"/>
        <source>Checks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="421"/>
        <source>Various security related information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/certificatemodel.cpp" line="610"/>
        <source>Header</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/daemoncertificatecollection.cpp" line="148"/>
        <source>Daemon certificate store</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/daemoncertificatecollection.cpp" line="152"/>
        <source>%1 banned list</source>
        <extracomment>The list of banned certificates for this account</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/daemoncertificatecollection.cpp" line="155"/>
        <source>%1 allowed list</source>
        <extracomment>The list of allowed certificates for this account</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/daemoncertificatecollection.cpp" line="160"/>
        <location filename="../src/foldercertificatecollection.cpp" line="198"/>
        <source>Certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/extensions/presencecollectionextension.cpp" line="38"/>
        <source>Presence tracking</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/extensions/securityevaluationextension.cpp" line="63"/>
        <source>Security evaluation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/fallbackpersoncollection.cpp" line="194"/>
        <location filename="../src/transitionalpersonbackend.cpp" line="150"/>
        <source>Contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localbookmarkcollection.cpp" line="212"/>
        <source>Local bookmarks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localbookmarkcollection.cpp" line="217"/>
        <location filename="../src/useractionmodel.cpp" line="532"/>
        <source>Bookmark</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localhistorycollection.cpp" line="195"/>
        <source>Local history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localhistorycollection.cpp" line="200"/>
        <source>History</source>
        <translation>تاریخچه</translation>
    </message>
    <message>
        <location filename="../src/localmacrocollection.cpp" line="190"/>
        <source>Local macros</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localmacrocollection.cpp" line="195"/>
        <source>Macro</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localrecordingcollection.cpp" line="101"/>
        <source>Local recordings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localrecordingcollection.cpp" line="106"/>
        <location filename="../src/localtextrecordingcollection.cpp" line="170"/>
        <source>Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localringtonecollection.cpp" line="220"/>
        <source>Local ringtones</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localringtonecollection.cpp" line="225"/>
        <source>Ringtone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localtextrecordingcollection.cpp" line="165"/>
        <source>Local text recordings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/numbercategory.cpp" line="72"/>
        <source>Phone number types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/numbercategorymodel.cpp" line="186"/>
        <source>Other</source>
        <translation>دیگر</translation>
    </message>
    <message>
        <location filename="../src/protocolmodel.cpp" line="50"/>
        <source>Ring Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/protocolmodel.cpp" line="51"/>
        <source>SIP Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="315"/>
        <source>Me</source>
        <translation>من</translation>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="38"/>
        <source>TLS is disabled, the negotiation won&apos;t be encrypted. Your communication will be vulnerable to snooping</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="40"/>
        <source>Your certificate and authority don&apos;t match, if your certificate require an authority, it won&apos;t work</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="41"/>
        <source>The outgoing server specified doesn&apos;t match the hostname or the one included in the certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="42"/>
        <source>The &quot;verify incoming certificate&quot; option is disabled, this leave you vulnerable to man in the middle attack</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="43"/>
        <source>The &quot;verify answer certificate&quot; option is disabled, this leave you vulnerable to man in the middle attack</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="44"/>
        <source>None of your certificate provide a private key, this is required. Please select a private key or use a certificate with one built-in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="47"/>
        <source>No certificate authority is provided, it won&apos;t be possible to validate if the answer certificates are valid. Some account may also not work.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="46"/>
        <source>No certificate has been provided. This is, for now, unsupported by Ring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="37"/>
        <source>Your media streams are not encrypted, please enable SDES</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="50"/>
        <source>Your certificate is expired, please contact your system administrator.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="51"/>
        <source>Your certificate is self signed. This break the chain of trust.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/tlsmethodmodel.cpp" line="64"/>
        <source>Default</source>
        <comment>Default TLS protocol version</comment>
        <translation>پیش‌گزیده</translation>
    </message>
    <message>
        <location filename="../src/transitionalpersonbackend.cpp" line="145"/>
        <source>Contact placeholders</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="517"/>
        <location filename="../src/useractionmodel.cpp" line="759"/>
        <source>Accept</source>
        <translation>قبول</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="61"/>
        <location filename="../src/api/call.h" line="77"/>
        <location filename="../src/useractionmodel.cpp" line="518"/>
        <location filename="../src/useractionmodel.cpp" line="771"/>
        <source>Hold</source>
        <translation>نگه داشتن</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="63"/>
        <source>Talking</source>
        <translation>در حال صحبت</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="65"/>
        <source>ERROR</source>
        <translation>خطا</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="67"/>
        <source>Outgoing requested</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="69"/>
        <source>Incoming</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="71"/>
        <source>Calling</source>
        <translation>در حال تماس</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="73"/>
        <source>Connecting</source>
        <translation>در حال اتّصال</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="75"/>
        <source>Searching</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="79"/>
        <source>Inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="81"/>
        <location filename="../src/api/call.h" line="83"/>
        <source>Finished</source>
        <translation>پایان یافته</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="85"/>
        <source>Communication established</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="87"/>
        <source>Auto answering</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="519"/>
        <source>Mute audio</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="520"/>
        <source>Mute video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="521"/>
        <source>Server transfer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="522"/>
        <source>Record</source>
        <translation>ضبط</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="523"/>
        <location filename="../src/useractionmodel.cpp" line="789"/>
        <source>Hangup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="524"/>
        <source>Join</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="525"/>
        <source>Add new</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="526"/>
        <source>Toggle video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="527"/>
        <source>Add a contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="528"/>
        <source>Add to existing contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="529"/>
        <source>Delete contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="530"/>
        <source>Email contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="531"/>
        <source>Copy contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="534"/>
        <source>Add phone number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="535"/>
        <source>Call again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="536"/>
        <source>Edit contact details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="537"/>
        <source>Remove from history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="786"/>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="756"/>
        <source>Call</source>
        <translation>تماس</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="533"/>
        <source>Open chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="768"/>
        <source>Unhold</source>
        <translation>در حال انتظار</translation>
    </message>
    <message>
        <location filename="../src/useractionmodel.cpp" line="779"/>
        <source>Cancel</source>
        <translation>لغو</translation>
    </message>
    <message>
        <location filename="../src/localprofilecollection.cpp" line="147"/>
        <source>Local profiles</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/localprofilecollection.cpp" line="152"/>
        <source>Profile Collection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/peerprofilecollection.cpp" line="141"/>
        <source>Peer profiles</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/peerprofilecollection.cpp" line="146"/>
        <source>Peers Profiles Collection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1231"/>
        <location filename="../src/conversationmodel.cpp" line="1596"/>
        <location filename="../src/conversationmodel.cpp" line="1846"/>
        <source>Invitation received</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1232"/>
        <source>Contact added</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1267"/>
        <location filename="../src/conversationmodel.cpp" line="1274"/>
        <source>Invitation accepted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1478"/>
        <source>ð Outgoing call</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1480"/>
        <source>ð Incoming call</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1493"/>
        <source>ð Outgoing call - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1496"/>
        <source>ð Incoming call - </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1500"/>
        <source>ð½ Missed outgoing call</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1502"/>
        <source>ð½ Missed incoming call</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RecentModel</name>
    <message>
        <location filename="../src/recentmodel.cpp" line="614"/>
        <source>Recent persons</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RingDeviceModel</name>
    <message>
        <location filename="../src/ringdevicemodel.cpp" line="110"/>
        <source>Id</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/ringdevicemodel.cpp" line="112"/>
        <source>Name</source>
        <translation>نام</translation>
    </message>
</context>
<context>
    <name>SecurityEvaluationModelPrivate</name>
    <message>
        <location filename="../src/securityevaluationmodel.cpp" line="683"/>
        <source>Authority</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TlsMethodModel</name>
    <message>
        <location filename="../src/tlsmethodmodel.cpp" line="101"/>
        <source>Automatic</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Video::SourceModel</name>
    <message>
        <location filename="../src/video/sourcemodel.cpp" line="95"/>
        <source>NONE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/video/sourcemodel.cpp" line="101"/>
        <source>SCREEN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/video/sourcemodel.cpp" line="107"/>
        <source>FILE</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>